summaryrefslogtreecommitdiff
path: root/win32
diff options
context:
space:
mode:
authornobu <nobu@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2006-09-08 19:49:02 +0000
committernobu <nobu@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2006-09-08 19:49:02 +0000
commit3a2cf78faae5361be34e9d0f1229b077913296a3 (patch)
treedba19b50be10ad06924b80ff3a20ec64252c385c /win32
parentd81f47cad6a8570e3c80ed664666f2e60ad2bd99 (diff)
* Makefile.in, win32/Makefile.sub (MINIRUBY): append MINIRUBYOPT.
* mkconfig.rb, ext/extmk.rb, lib/mkmf.rb, win32/mkexports.rb: suppress warnings with $VERBOSE. * win32/resource.rb: add more info. git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/branches/ruby_1_8@10893 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
Diffstat (limited to 'win32')
-rw-r--r--win32/Makefile.sub2
-rw-r--r--win32/mkexports.rb2
-rw-r--r--win32/resource.rb20
3 files changed, 12 insertions, 12 deletions
diff --git a/win32/Makefile.sub b/win32/Makefile.sub
index 23c73be382..9a0004cd00 100644
--- a/win32/Makefile.sub
+++ b/win32/Makefile.sub
@@ -160,7 +160,7 @@ EXEEXT = .exe
PROGRAM=$(RUBY_INSTALL_NAME)$(EXEEXT)
WPROGRAM=$(RUBYW_INSTALL_NAME)$(EXEEXT)
RUBYDEF = $(RUBY_SO_NAME).def
-MINIRUBY = .\miniruby$(EXEEXT)
+MINIRUBY = .\miniruby$(EXEEXT) $(MINIRUBYOPT)
RUNRUBY = .\ruby$(EXEEXT) "$(srcdir)/runruby.rb" --extout="$(EXTOUT)" --
!if !defined(STACK)
diff --git a/win32/mkexports.rb b/win32/mkexports.rb
index 3859381935..214e4c6772 100644
--- a/win32/mkexports.rb
+++ b/win32/mkexports.rb
@@ -1,5 +1,7 @@
#!./miniruby -s
+$name = $library = $description = nil
+
SYM = {}
objs = ARGV.collect {|s| s.tr('/', '\\')}
diff --git a/win32/resource.rb b/win32/resource.rb
index 0bfebf2d63..1c12075183 100644
--- a/win32/resource.rb
+++ b/win32/resource.rb
@@ -29,16 +29,14 @@ else
end
ruby_icon = rubyw_icon = nil
-[$ruby_name, 'ruby'].each do |i|
+[$ruby_name, 'ruby'].find do |i|
if i = icons[i]
ruby_icon = "1 ICON DISCARDABLE "+i.dump+"\n"
- break
end
end
-[$rubyw_name, 'rubyw'].each do |i|
+[$rubyw_name, 'rubyw'].find do |i|
if i = icons[i]
rubyw_icon = "1 ICON DISCARDABLE "+i.dump+"\n"
- break
end
end
dll_icons = []
@@ -46,11 +44,11 @@ icons.keys.sort.each do |i|
dll_icons << "#{dll_icons.size + 1} ICON DISCARDABLE "+icons[i].dump+"\n"
end
-[ # base name extension file type icons
- [$ruby_name, CONFIG["EXEEXT"], 'VFT_APP', ruby_icon],
- [$rubyw_name, CONFIG["EXEEXT"], 'VFT_APP', rubyw_icon || ruby_icon],
- [$so_name, '.dll', 'VFT_DLL', dll_icons],
-].each do |base, ext, type, icons|
+[ # base name extension file type desc, icons
+ [$ruby_name, CONFIG["EXEEXT"], 'VFT_APP', 'CUI', ruby_icon],
+ [$rubyw_name, CONFIG["EXEEXT"], 'VFT_APP', 'GUI', rubyw_icon || ruby_icon],
+ [$so_name, '.dll', 'VFT_DLL', 'DLL', dll_icons.join],
+].each do |base, ext, type, desc, icons|
open(base + '.rc', "w") { |f|
f.binmode if /mingw/ =~ RUBY_PLATFORM
@@ -60,7 +58,7 @@ end
#include <winver.h>
#endif
-#{icons}
+#{icons || ''}
VS_VERSION_INFO VERSIONINFO
FILEVERSION #{fversion}
PRODUCTVERSION #{fversion}
@@ -74,7 +72,7 @@ BEGIN
BEGIN
BLOCK "000004b0"
BEGIN
- VALUE "FileDescription", "Ruby interpreter\\0"
+ VALUE "FileDescription", "Ruby interpreter (#{desc}) #{RUBY_VERSION} [#{RUBY_PLATFORM}]\\0"
VALUE "FileVersion", "#{fversion}\\0"
VALUE "Home Page", "http://www.ruby-lang.org/\\0"
VALUE "InternalName", "#{base + ext}\\0"